@@ -233,6 +233,9 @@ INVALIDPARAMETER_IMAGEIDSSNAPSHOTIDSMUSTONE = 'InvalidParameter.ImageIdsSnapshot
 # 当前接口不支持实例镜像。
 INVALIDPARAMETER_INSTANCEIMAGENOTSUPPORT = 'InvalidParameter.InstanceImageNotSupport'
 
+# 不支持设置公网带宽相关信息。
+INVALIDPARAMETER_INTERNETACCESSIBLENOTSUPPORTED = 'InvalidParameter.InternetAccessibleNotSupported'
+
 # 云盘资源售罄。
 INVALIDPARAMETER_INVALIDCLOUDDISKSOLDOUT = 'InvalidParameter.InvalidCloudDiskSoldOut'
 
@@ -914,9 +917,6 @@ UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILY = 'UnsupportedOperation.Uns
 # 非ARM机型不支持调整到ARM机型。
 UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOARM = 'UnsupportedOperation.UnsupportedChangeInstanceFamilyToARM'
 
-# 目标机型是SA3, 不支持变配。
-UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCEFAMILYTOSA3 = 'UnsupportedOperation.UnsupportedChangeInstanceFamilyToSA3'
-
 # 不支持实例变配到此类型机型。
 UNSUPPORTEDOPERATION_UNSUPPORTEDCHANGEINSTANCETOTHISINSTANCEFAMILY = 'UnsupportedOperation.UnsupportedChangeInstanceToThisInstanceFamily'
 
