@@ -1,5 +1,5 @@
 # -*- coding: utf8 -*-
-# Copyright (c) 2017-2018 THL A29 Limited, a Tencent company. All Rights Reserved.
+# Copyright (c) 2017-2021 THL A29 Limited, a Tencent company. All Rights Reserved.
 #
 # Licensed under the Apache License, Version 2.0 (the "License");
 # you may not use this file except in compliance with the License.
@@ -13,6 +13,8 @@
 # See the License for the specific language governing permissions and
 # limitations under the License.
 
+import warnings
+
 from tencentcloud.common.abstract_model import AbstractModel
 
 
@@ -22,7 +24,7 @@ class EvaluationRequest(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionId: 图片唯一标识，一张图片一个SessionId；
         :type SessionId: str
         :param Image: 图片数据，需要使用base64对图片的二进制数据进行编码，与url参数二者填一即可；
@@ -79,6 +81,13 @@ class EvaluationRequest(AbstractModel):
         self.PdfPageIndex = params.get("PdfPageIndex")
         self.LaTex = params.get("LaTex")
         self.RejectVagueArithmetic = params.get("RejectVagueArithmetic")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class EvaluationResponse(AbstractModel):
@@ -87,7 +96,7 @@ class EvaluationResponse(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param SessionId: 图片唯一标识，一张图片一个SessionId；
         :type SessionId: str
         :param Items: 识别出的算式信息；
@@ -122,7 +131,7 @@ class Item(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Item: 识别的算式是否正确，算式运算结果: ‘YES’:正确 ‘NO’: 错误 ‘NA’: 非法参数
         :type Item: str
         :param ItemString: 识别出的算式，识别出的文本行字符串
@@ -160,6 +169,13 @@ class Item(AbstractModel):
         self.ExpressionType = params.get("ExpressionType")
         self.ItemConf = params.get("ItemConf")
         self.QuestionId = params.get("QuestionId")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
 
 
 class ItemCoord(AbstractModel):
@@ -168,7 +184,7 @@ class ItemCoord(AbstractModel):
     """
 
     def __init__(self):
-        """
+        r"""
         :param Height: 算式高度
         :type Height: int
         :param Width: 算式宽度
@@ -188,4 +204,11 @@ class ItemCoord(AbstractModel):
         self.Height = params.get("Height")
         self.Width = params.get("Width")
         self.X = params.get("X")
-        self.Y = params.get("Y")
\ No newline at end of file
+        self.Y = params.get("Y")
+        memeber_set = set(params.keys())
+        for name, value in vars(self).items():
+            if name in memeber_set:
+                memeber_set.remove(name)
+        if len(memeber_set) > 0:
+            warnings.warn("%s fileds are useless." % ",".join(memeber_set))
+        
\ No newline at end of file
