@@ -27,7 +27,7 @@ class SesClient(AbstractClient):
 
 
     def BatchSendEmail(self, request):
-        """您可以通过此API批量发送TEXT或者HTML邮件，适用于营销类、通知类邮件。默认仅支持使用模板发送邮件，如需发送自定义内容，请单独联系商务开通此功能。批量发送之前，需先创建收件人列表，和收件人地址，并通过收件人列表id来进行发送。批量发送任务支持定时发送和周期重复发送，定时发送需传TimedParam，周期重复发送需传CycleParam
+        """您可以通过此API批量发送TEXT或者HTML邮件，适用于营销类、通知类邮件。默认仅支持使用模板发送邮件。批量发送之前，需先创建收件人列表，和收件人地址，并通过收件人列表id来进行发送。批量发送任务支持定时发送和周期重复发送，定时发送需传TimedParam，周期重复发送需传CycleParam
 
         :param request: Request instance for BatchSendEmail.
         :type request: :class:`tencentcloud.ses.v20201002.models.BatchSendEmailRequest`
@@ -36,7 +36,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("BatchSendEmail", params)
+            headers = request.headers
+            body = self.call("BatchSendEmail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.BatchSendEmailResponse()
@@ -64,7 +65,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailAddress", params)
+            headers = request.headers
+            body = self.call("CreateEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailAddressResponse()
@@ -92,7 +94,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailIdentity", params)
+            headers = request.headers
+            body = self.call("CreateEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailIdentityResponse()
@@ -121,7 +124,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateEmailTemplate", params)
+            headers = request.headers
+            body = self.call("CreateEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateEmailTemplateResponse()
@@ -149,7 +153,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReceiver", params)
+            headers = request.headers
+            body = self.call("CreateReceiver", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReceiverResponse()
@@ -168,7 +173,7 @@ class SesClient(AbstractClient):
 
 
     def CreateReceiverDetail(self, request):
-        """在创建完收件人列表后，向这个收件人列表中批量增加收件人邮箱地址，一次最大支持10W，异步完成处理。收件人列表只可以上传一次，不可追加上传。数据量比较大的时候，上传可能需要一点时间，可以通过查询收件人列表了解上传状态和上传数量
+        """在创建完收件人列表后，向这个收件人列表中批量增加收件人邮箱地址，一次最大支持2万，异步完成处理。数据量比较大的时候，上传可能需要一点时间，可以通过查询收件人列表了解上传状态和上传数量。本接口与接口CreateReceiverDetailWithData的功能特性基本一致，只是不支持上传发信时的模板参数。用户首先调用创建收件人列表接口-CreateReceiver后，然后调用本接口传入收件人地址，最后使用批量发送邮件接口-BatchSendEmail，即可完成批量发信。本接口也支持追加收件人地址，也不支持去重，需要用户自己保证收件人地址不重复。本接口一次请求的收件人地址数量限制为2W条，但收件人列表中收件人地址的总量不能超过一定的数量，目前是限制5万条。
 
         :param request: Request instance for CreateReceiverDetail.
         :type request: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailRequest`
@@ -177,7 +182,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReceiverDetail", params)
+            headers = request.headers
+            body = self.call("CreateReceiverDetail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReceiverDetailResponse()
@@ -196,7 +202,7 @@ class SesClient(AbstractClient):
 
 
     def CreateReceiverDetailWithData(self, request):
-        """添加收件人地址附带模板参数
+        """添加收件人地址附带模板参数，使用本接口在添加收件人地址的同时传入模板参数，使每一个收件人地址在发信的时候使用的模板变量取值不同。用户首先调用创建收件人列表接口-CreateReceiver后，然后调用本接口传入收件人地址和发信时的模板参数，最后使用批量发送邮件接口-BatchSendEmail，即可完成批量发信。需要注意的是在使用本接口后BatchSendEmail接口中的Template参数不需再传。用户也可以在控制台上邮件发送-收件人列表菜单中，通过导入文件的方式，导入收件人地址和模板变量和参数值。本接口一次请求的收件人地址数量限制为2W条，本接口同时也可以用来向已经上传完成的收件人列表追加收件人地址，但收件人列表中收件人地址的总量不能超过一定的数量，目前是限制5万条。本接口不支持去除重复的收件人地址，用户需要自己保证上传和追加地址不重复，不与之前上传的地址重复。
 
         :param request: Request instance for CreateReceiverDetailWithData.
         :type request: :class:`tencentcloud.ses.v20201002.models.CreateReceiverDetailWithDataRequest`
@@ -205,7 +211,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("CreateReceiverDetailWithData", params)
+            headers = request.headers
+            body = self.call("CreateReceiverDetailWithData", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.CreateReceiverDetailWithDataResponse()
@@ -233,7 +240,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteBlackList", params)
+            headers = request.headers
+            body = self.call("DeleteBlackList", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteBlackListResponse()
@@ -261,7 +269,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailAddress", params)
+            headers = request.headers
+            body = self.call("DeleteEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailAddressResponse()
@@ -289,7 +298,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailIdentity", params)
+            headers = request.headers
+            body = self.call("DeleteEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailIdentityResponse()
@@ -317,7 +327,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteEmailTemplate", params)
+            headers = request.headers
+            body = self.call("DeleteEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteEmailTemplateResponse()
@@ -345,7 +356,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("DeleteReceiver", params)
+            headers = request.headers
+            body = self.call("DeleteReceiver", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.DeleteReceiverResponse()
@@ -373,7 +385,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEmailIdentity", params)
+            headers = request.headers
+            body = self.call("GetEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEmailIdentityResponse()
@@ -401,7 +414,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetEmailTemplate", params)
+            headers = request.headers
+            body = self.call("GetEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetEmailTemplateResponse()
@@ -430,7 +444,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetSendEmailStatus", params)
+            headers = request.headers
+            body = self.call("GetSendEmailStatus", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetSendEmailStatusResponse()
@@ -458,7 +473,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("GetStatisticsReport", params)
+            headers = request.headers
+            body = self.call("GetStatisticsReport", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.GetStatisticsReportResponse()
@@ -486,7 +502,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListBlackEmailAddress", params)
+            headers = request.headers
+            body = self.call("ListBlackEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListBlackEmailAddressResponse()
@@ -514,7 +531,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailAddress", params)
+            headers = request.headers
+            body = self.call("ListEmailAddress", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailAddressResponse()
@@ -542,7 +560,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailIdentities", params)
+            headers = request.headers
+            body = self.call("ListEmailIdentities", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailIdentitiesResponse()
@@ -570,7 +589,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListEmailTemplates", params)
+            headers = request.headers
+            body = self.call("ListEmailTemplates", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListEmailTemplatesResponse()
@@ -598,7 +618,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListReceivers", params)
+            headers = request.headers
+            body = self.call("ListReceivers", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListReceiversResponse()
@@ -626,7 +647,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("ListSendTasks", params)
+            headers = request.headers
+            body = self.call("ListSendTasks", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.ListSendTasksResponse()
@@ -645,7 +667,7 @@ class SesClient(AbstractClient):
 
 
     def SendEmail(self, request):
-        """您可以通过此API发送TEXT或者HTML邮件，适用于触发类邮件（验证码、交易类）。默认仅支持使用模板发送邮件，如需发送自定义内容，请单独联系商务开通此功能。
+        """您可以通过此API发送HTML或者TEXT邮件，适用于触发类邮件（验证码、交易类）。默认仅支持使用模板发送邮件。
 
         :param request: Request instance for SendEmail.
         :type request: :class:`tencentcloud.ses.v20201002.models.SendEmailRequest`
@@ -654,7 +676,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("SendEmail", params)
+            headers = request.headers
+            body = self.call("SendEmail", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.SendEmailResponse()
@@ -682,7 +705,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateEmailIdentity", params)
+            headers = request.headers
+            body = self.call("UpdateEmailIdentity", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateEmailIdentityResponse()
@@ -710,7 +734,8 @@ class SesClient(AbstractClient):
         """
         try:
             params = request._serialize()
-            body = self.call("UpdateEmailTemplate", params)
+            headers = request.headers
+            body = self.call("UpdateEmailTemplate", params, headers=headers)
             response = json.loads(body)
             if "Error" not in response["Response"]:
                 model = models.UpdateEmailTemplateResponse()
